/* DCTC - a Direct Connect text clone for Linux
 * Copyright (C) 2001 Eric Prevoteau
 *
 * macro.h: Copyright (C) Eric Prevoteau <www@a2pb.gotdns.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*
$Id: macro.h,v 1.2 2003/12/28 08:12:38 uid68112 Exp $
*/

#ifndef __MACRO_H__
#define __MACRO_H__

#define SKIP_SPACE(z)         { while((*z)&&(isspace(*z))) z++; }
#define SKIP_UNTIL_SPACE(z)   { while((*z)&&(!isspace(*z))) z++; }

#define max(a,b)     (((a)>(b))?(a):(b))
#define min(a,b)     (((a)<(b))?(a):(b))

#endif
